summaryrefslogtreecommitdiffstats
path: root/src/ex_getln.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/ex_getln.c')
-rw-r--r--src/ex_getln.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/ex_getln.c b/src/ex_getln.c
index a5196fcf6b..2a1fe3dc6f 100644
--- a/src/ex_getln.c
+++ b/src/ex_getln.c
@@ -3892,6 +3892,7 @@ redrawcmd(void)
return;
}
+ sb_text_restart_cmdline();
msg_start();
redrawcmdprompt();
@@ -4106,7 +4107,7 @@ get_cmdline_info(void)
#if defined(FEAT_EVAL) || defined(FEAT_CMDWIN) || defined(PROTO)
/*
* Get pointer to the command line info to use. save_ccline() may clear
* ccline and put the previous value in prev_ccline.
*/
static cmdline_info_T *
@@ -4106,7 +4107,7 @@ get_cmdline_info(void)
#if defined(FEAT_EVAL) || defined(FEAT_CMDWIN) || defined(PROTO)
/*
- * Get pointer to the command line info to use. save_ccline() may clear
+ * Get pointer to the command line info to use. save_cmdline() may clear
* ccline and put the previous value in prev_ccline.
*/